//
//  StrataAppDelegate.m
//  Strata
//
//  Created by Grant Davis on 5/6/10.
//  Copyright Factory Design Labs 2010. All rights reserved.
//

#import "StrataAppDelegate.h"
#import "HomeViewController.h"
#import "UINavigationController+TabBar.h"
#import "ModalViewController.h"

@interface StrataAppDelegate (Private)

- (void)setupEnvironment;
- (void)buildViewControllers;
- (void)buildTabBarController;

- (void)buildNavigationControllerSection;
- (void)buildModalSection;

@end



@implementation StrataAppDelegate

@synthesize window;


- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions {    

	[self setupEnvironment];
	
	// build main application views
	[self buildViewControllers];
	
	// create tab bar with the view controllers
	[self buildTabBarController];
	
	[window addSubview:tabBarController.view];
    [window makeKeyAndVisible];
	
	return YES;
}



- (void)setupEnvironment
{
	[[UIApplication sharedApplication] setStatusBarStyle:UIStatusBarStyleBlackOpaque animated:NO];
}


- (void)buildViewControllers
{
	// build controllers array
	controllers = [[NSMutableArray array] retain];
	
	[self buildNavigationControllerSection];
	
	[self buildModalSection];
	
}

- (void)buildNavigationControllerSection
{
	// build a nav controller as top level view controller for the first tab
	UINavigationController *firstSectionNavController = [[[UINavigationController alloc] initWithTitle:@"Navigation Controller" 
																							   tabIcon:[UIImage imageNamed:@"home-icon.png"]  
																						   navBarStyle:UIBarStyleBlackOpaque 
																								andTag:0] autorelease];
	[controllers addObject:firstSectionNavController];
	
	// create the first controller for the nav controller
	UIViewController *homeController = [[[HomeViewController alloc] initWithNavigationController:firstSectionNavController title:@"Home"] autorelease];
	[firstSectionNavController setViewControllers:[NSArray arrayWithObject:homeController]];
}


// creates a section that pops a view controller as a modal
- (void)buildModalSection
{
	UINavigationController *thirdSectionNavController = [[[UINavigationController alloc] initWithTitle:@"Modal" 
																							   tabIcon:[UIImage imageNamed:@"search-icon.png"]  
																						   navBarStyle:UIBarStyleBlackOpaque 
																								andTag:0] autorelease];
	[controllers addObject:thirdSectionNavController];
	UIViewController *thirdSectionController = [[[ModalViewController alloc] initWithNavigationController:thirdSectionNavController 
																									title:@"Modal Fun"] autorelease];
	[thirdSectionNavController setViewControllers:[NSArray arrayWithObject:thirdSectionController]];
}



- (void)buildTabBarController
{
	// create the top level controller
	tabBarController = [[UITabBarController alloc] initWithNibName:nil bundle:nil];
	
	// add controllers to tab bar
	[tabBarController setViewControllers:controllers animated:NO];
	
	// set first selection
	[tabBarController setSelectedIndex:0];
}


- (void)dealloc {
	[tabBarController release];
	[controllers release];
    [window release];
    [super dealloc];
}


@end
